@@ -6,10 +6,11 @@
 ----------------------------------------------------------------------------
 
 local remotedostring = assert (remotedostring, "There is no `remotedostring'.  Probably not in a slave state")
+
 -- creating persistent table at master state.
 assert (remotedostring[[_state_persistent_table_ = _state_persistent_table_ or {}]])
 
-module"stable"
+local _M = {}
 
 ----------------------------------------------------------------------------
 _COPYRIGHT = "Copyright (C) 2006 Kepler Project"
@@ -17,12 +18,15 @@ _DESCRIPTION = "State persistent table"
 _VERSION = "Stable 1.0"
 
 ----------------------------------------------------------------------------
-function get (i)
+function _M.get (i)
 	local ok, value = remotedostring ("return _state_persistent_table_[...]", i)
 	return value
 end
 
 ----------------------------------------------------------------------------
-function set (i, v)
+function _M.set (i, v)
 	remotedostring ("_state_persistent_table_[select(1,...)] = select(2,...)", i, v)
 end
+
+return _M
+
